"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useStopwatch = void 0;
const vue_1 = require("vue");
const utils_1 = require("./utils");
const hooks_1 = require("./hooks");
const epochSeconds = () => new Date().getTime();
const useStopwatch = (autoStart = true, offsetTimestamp) => {
    let interval;
    const passedSeconds = vue_1.ref(utils_1.Time.getSecondsFromExpiry(offsetTimestamp, true) || 0);
    const prevTime = vue_1.ref(epochSeconds());
    const seconds = vue_1.ref(passedSeconds.value + utils_1.Time.getSecondsFromPrevTime(prevTime.value || 0, true).value);
    const isRunning = vue_1.ref(autoStart);
    function start() {
        const newPrevTime = epochSeconds();
        prevTime.value = newPrevTime;
        isRunning.value = true;
        seconds.value =
            passedSeconds.value + utils_1.Time.getSecondsFromPrevTime(newPrevTime, true).value;
        interval = hooks_1.useInterval(() => {
            seconds.value =
                passedSeconds.value + utils_1.Time.getSecondsFromPrevTime(prevTime.value, true).value;
        }, isRunning.value ? 1000 : false);
    }
    function pause() {
        passedSeconds.value = seconds.value;
        isRunning.value = false;
        if (interval)
            interval.remove();
    }
    function reset(offset = 0, newAutoStart = true) {
        isRunning.value = newAutoStart;
        passedSeconds.value = utils_1.Time.getSecondsFromExpiry(offset, true).value || 0;
        start();
    }
    return Object.assign(Object.assign({}, utils_1.Time.getTimeFromSeconds(seconds)), { start,
        pause,
        reset,
        isRunning });
};
exports.useStopwatch = useStopwatch;
//# sourceMappingURL=useStopwatch.js.map