"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useTimer = void 0;
// import { useState } from 'react';
const vue_1 = require("vue");
const utils_1 = require("./utils");
const hooks_1 = require("./hooks");
const DEFAULT_DELAY = 1000;
function getDelayFromExpiryTimestamp(expiryTimestamp) {
    if (!utils_1.Validate.expiryTimestamp(expiryTimestamp)) {
        return null;
    }
    const seconds = utils_1.Time.getSecondsFromExpiry(expiryTimestamp);
    const extraMilliSeconds = Math.floor((seconds.value - Math.floor(seconds.value)) * 1000);
    return extraMilliSeconds > 0 ? extraMilliSeconds : DEFAULT_DELAY;
}
const useTimer = (expiry = 60, autoStart = true) => {
    let interval;
    const state = vue_1.reactive({
        expiryTimestamp: expiry,
        seconds: utils_1.Time.getSecondsFromExpiry(expiry),
        isRunning: autoStart,
        isExpired: false,
        didStart: autoStart,
        delay: getDelayFromExpiryTimestamp(expiry)
    });
    function _handleExpire() {
        state.isExpired = true;
        state.isRunning = false;
        state.delay = null;
        if (interval)
            interval.remove();
    }
    function pause() {
        state.isRunning = false;
        if (interval)
            interval.remove();
    }
    function restart(newExpiryTimestamp = expiry, newAutoStart = true) {
        state.delay = getDelayFromExpiryTimestamp(newExpiryTimestamp);
        state.didStart = newAutoStart;
        state.isExpired = false;
        state.isRunning = newAutoStart;
        state.expiryTimestamp = newExpiryTimestamp;
        state.seconds = utils_1.Time.getSecondsFromExpiry(newExpiryTimestamp).value;
        interval = hooks_1.useInterval(() => {
            if (state.delay !== DEFAULT_DELAY) {
                state.delay = DEFAULT_DELAY;
            }
            const secondsValue = utils_1.Time.getSecondsFromExpiry(state.expiryTimestamp);
            state.seconds = secondsValue.value;
            if (secondsValue.value <= 0) {
                _handleExpire();
            }
        }, state.isRunning ? state.delay : null);
    }
    function resume() {
        const time = new Date();
        time.setMilliseconds(time.getMilliseconds() + state.seconds * 1000);
        restart(time.getTime());
    }
    function start() {
        if (state.didStart) {
            state.seconds = utils_1.Time.getSecondsFromExpiry(state.expiryTimestamp).value;
            state.isRunning = true;
        }
        else {
            resume();
        }
    }
    restart(expiry, autoStart);
    return Object.assign(Object.assign({}, utils_1.Time.getTimeFromSeconds(vue_1.toRef(state, 'seconds'))), { start,
        pause,
        resume,
        restart, isRunning: vue_1.toRef(state, 'isRunning'), isExpired: vue_1.toRef(state, 'isExpired') });
};
exports.useTimer = useTimer;
//# sourceMappingURL=useTimer.js.map