"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vue_1 = require("vue");
class Time {
    static getTimeFromSeconds(secs) {
        const totalSeconds = vue_1.computed(() => Math.ceil(secs.value));
        const days = vue_1.computed(() => Math.floor(totalSeconds.value / (60 * 60 * 24)));
        const hours = vue_1.computed(() => Math.floor((totalSeconds.value % (60 * 60 * 24)) / (60 * 60)));
        const minutes = vue_1.computed(() => Math.floor((totalSeconds.value % (60 * 60)) / 60));
        const seconds = vue_1.computed(() => Math.floor(totalSeconds.value % 60));
        return {
            seconds,
            minutes,
            hours,
            days,
        };
    }
    static getSecondsFromExpiry(expiry, shouldRound) {
        const now = new Date().getTime();
        const milliSecondsDistance = expiry - now;
        if (milliSecondsDistance > 0) {
            const val = milliSecondsDistance / 1000;
            return vue_1.ref(shouldRound ? Math.round(val) : val);
        }
        return vue_1.ref(0);
    }
    static getSecondsFromPrevTime(prevTime, shouldRound) {
        const now = new Date().getTime();
        const milliSecondsDistance = now - prevTime;
        if (milliSecondsDistance > 0) {
            const val = milliSecondsDistance / 1000;
            return vue_1.ref(shouldRound ? Math.round(val) : val);
        }
        return vue_1.ref(0);
    }
    static getSecondsFromTimeNow() {
        const now = new Date();
        const currentTimestamp = now.getTime();
        const offset = now.getTimezoneOffset() * 60;
        return vue_1.ref(currentTimestamp / 1000 - offset);
    }
    static getFormattedTimeFromSeconds(totalSeconds, format) {
        const { seconds: secondsValue, minutes, hours, } = Time.getTimeFromSeconds(totalSeconds);
        const ampm = vue_1.computed(() => format === '12-hour' ? (hours.value >= 12 ? 'pm' : 'am') : '');
        const hoursValue = vue_1.computed(() => format === '12-hour' ? hours.value % 12 : hours.value);
        return {
            seconds: secondsValue,
            minutes,
            hours: hoursValue,
            ampm,
        };
    }
}
exports.default = Time;
//# sourceMappingURL=Time.js.map